@@ -161,7 +161,7 @@ If a folder name begins with PREFIX, use BACKEND."
 
 (defmacro elmo-folder-send (folder message &rest args)
   "Let FOLDER receive the MESSAGE with ARGS."
-  (` (luna-send (, folder) (, message) (, folder) (,@ args))))
+  `(luna-send ,folder ,message ,folder ,@args))
 
 ;;;###autoload
 (defun elmo-make-folder (name &optional non-persistent mime-charset)
@@ -1498,7 +1498,7 @@ If Optional LOCAL is non-nil, don't update server flag."
 	    (while t
 	      (setq in (read-from-minibuffer "Update number: "
 					     (int-to-string in))
-		    in (string-to-int in))
+		    in (string-to-number in))
 	      (if (< len in)
 		  (throw 'end len))
 	      (if (y-or-n-p (format
