@@ -27,13 +27,13 @@
 ;;; Commentary:
 ;;
 
+;;; Code:
+
 (require 'wl-summary)
 (require 'wl-thread)
 (require 'wl-folder)
 (require 'elmo)
 
-;;; Code:
-
 (eval-when-compile
   (require 'wl-util)
   (require 'elmo-archive))
@@ -73,10 +73,10 @@
 	 (error "Invalid marks: %s" wl-summary-expire-reserve-marks))))
 
 (defmacro wl-expire-make-sortable-date (date)
-  (` (timezone-make-sortable-date
-      (aref (, date) 0) (aref (, date) 1) (aref (, date) 2)
-      (timezone-make-time-string
-       (aref (, date) 3) (aref (, date) 4) (aref (, date) 5)))))
+  `(timezone-make-sortable-date
+    (aref ,date 0) (aref ,date 1) (aref ,date 2)
+    (timezone-make-time-string
+     (aref ,date 3) (aref ,date 4) (aref ,date 5))))
 
 ;; New functions to avoid accessing to the msgdb directly.
 (defsubst wl-expire-message-p (folder number)
@@ -387,7 +387,7 @@ Refile to archive folder followed the number of message in one archive folder."
 	       (setq dels (nth 1 tmp)))
       (wl-append deleted-list (car (wl-expire-delete folder dels))))
     (setq delete-list (car tmp)
-	  filenum (string-to-int (nth 3 tmp))
+	  filenum (string-to-number (nth 3 tmp))
 	  len (nth 4 tmp)
 	  arc-len len)
     (catch 'done
