@@ -34,6 +34,7 @@
 (require 'wl-vars)
 (require 'wl-util)
 (eval-when-compile
+  (require 'cl)				; cadaar, cddaar
   (require 'elmo-msgdb))		; for inline functions
 
 (defvar wl-score-edit-header-char
@@ -166,7 +167,7 @@ Remove Re, Was, Fwd etc."
 (defun wl-score-overview-entity-get-lines (entity)
   (let ((lines (elmo-message-entity-field entity 'lines)))
     (and lines
-	 (string-to-int lines))))
+	 (string-to-number lines))))
 
 (defun wl-score-overview-entity-get-xref (entity)
   (or (elmo-message-entity-field entity 'xref)
@@ -177,7 +178,11 @@ Remove Re, Was, Fwd etc."
 	   (string= s1 s2))))
 
 (defsubst wl-score-ov-entity-get (entity index &optional extra)
-  (elmo-message-entity-field entity (if extra (intern extra) index)))
+  (elmo-message-entity-field entity (if extra (intern extra) index)
+			     ;; FIXME
+			     (if (or (eq index 'to) (eq index 'cc))
+				 'string
+			       nil)))
 
 (defun wl-score-string< (a1 a2)
   (string-lessp (wl-score-ov-entity-get (car a1) wl-score-index)
@@ -534,13 +539,13 @@ Set `wl-score-cache' nil."
     nil))
 
 (defmacro wl-score-put-alike ()
-  (` (elmo-set-hash-val (format "#%d" (wl-count-lines))
-			alike
-			wl-score-alike-hashtb)))
+  '(elmo-set-hash-val (format "#%d" (wl-count-lines))
+		      alike
+		      wl-score-alike-hashtb))
 
 (defmacro wl-score-get-alike ()
-  (` (elmo-get-hash-val (format "#%d" (wl-count-lines))
-			wl-score-alike-hashtb)))
+  '(elmo-get-hash-val (format "#%d" (wl-count-lines))
+		      wl-score-alike-hashtb))
 
 (defun wl-score-insert-header (header messages &optional extra-header)
   (let ((mime-decode (nth 3 (assoc header wl-score-header-index)))
@@ -564,7 +569,8 @@ Set `wl-score-cache' nil."
 	  (setq this (wl-score-ov-entity-get (car art)
 					     wl-score-index
 					     extra-header))
-	  (and this (setq this (std11-unfold-string this)))
+	  (when (stringp this)
+	    (setq this (std11-unfold-string this)))
 	  (if (equal last this)
 	      ;; O(N*H) cons-cells used here, where H is the number of
 	      ;; headers.
@@ -810,7 +816,7 @@ Set `wl-score-cache' nil."
   "Automatically mark messages with score below SCORE as read."
   (interactive
    (list (or (and current-prefix-arg (prefix-numeric-value current-prefix-arg))
-	     (string-to-int (read-string "Mark below: ")))))
+	     (string-to-number (read-string "Mark below: ")))))
   (setq score (or score wl-summary-default-score 0))
   (wl-score-set 'mark (list score))
   (wl-score-set 'touched '(t))
@@ -821,7 +827,7 @@ Set `wl-score-cache' nil."
   "Automatically expunge messages with score below SCORE."
   (interactive
    (list (or (and current-prefix-arg (prefix-numeric-value current-prefix-arg))
-	     (string-to-int (read-string "Expunge below: ")))))
+	     (string-to-number (read-string "Expunge below: ")))))
   (setq score (or score wl-summary-default-score 0))
   (wl-score-set 'expunge (list score))
   (wl-score-set 'touched '(t)))
@@ -867,7 +873,7 @@ Set `wl-score-cache' nil."
     ;; transform from string to int.
     (when (eq (nth 1 (assoc (car entry) wl-score-header-index))
 	      'wl-score-integer)
-      (setq match (string-to-int match)))
+      (setq match (string-to-number match)))
     ;; set score
     (if score
 	(setq lscore rscore)
@@ -1056,7 +1062,7 @@ Set `wl-score-cache' nil."
 
 	  ;; read the score.
 	  (unless (or score increase)
-	    (setq score (string-to-int (read-string "Set score: ")))))
+	    (setq score (string-to-number (read-string "Set score: ")))))
       (message "")
       (wl-score-kill-help-buffer))
 
