@@ -35,6 +35,10 @@
 (require 'bytecomp)
 (require 'elmo-util)
 (require 'elmo-flag)
+(require 'wl-vars)
+(eval-when-compile (require 'elmo-pop3))
+(eval-when-compile (require 'cl))
+(eval-when-compile (require 'static))
 
 (condition-case nil (require 'pp) (error nil))
 
@@ -239,12 +243,12 @@ even when invalid character is contained."
 
 (defmacro wl-match-string (pos string)
   "Substring POSth matched STRING."
-  (` (substring (, string) (match-beginning (, pos)) (match-end (, pos)))))
+  `(substring ,string (match-beginning ,pos) (match-end ,pos)))
 
 (defmacro wl-match-buffer (pos)
   "Substring POSth matched from the current buffer."
-  (` (buffer-substring-no-properties
-      (match-beginning (, pos)) (match-end (, pos)))))
+  `(buffer-substring-no-properties
+    (match-beginning ,pos) (match-end ,pos)))
 
 (put 'wl-as-coding-system 'lisp-indent-function 1)
 (put 'wl-as-mime-charset 'lisp-indent-function 1)
@@ -253,21 +257,21 @@ even when invalid character is contained."
   (cond
    (wl-on-mule3
     (defmacro wl-as-coding-system (coding-system &rest body)
-      (` (let ((coding-system-for-read (, coding-system))
-	       (coding-system-for-write (, coding-system)))
-	   (,@ body)))))
+      `(let ((coding-system-for-read ,coding-system)
+	     (coding-system-for-write ,coding-system))
+	 ,@body)))
    (wl-on-mule
     (defmacro wl-as-coding-system (coding-system &rest body)
-      (` (let ((file-coding-system-for-read (, coding-system))
-	       (file-coding-system (, coding-system)))
-	   (,@ body)))))
+      `(let ((file-coding-system-for-read ,coding-system)
+	     (file-coding-system ,coding-system))
+	 ,@body)))
    (t
     (defmacro wl-as-coding-system (coding-system &rest body)
-      (` (progn (,@ body)))))))
+      `(progn ,@body)))))
 
 (defmacro wl-as-mime-charset (mime-charset &rest body)
-  (` (wl-as-coding-system (mime-charset-to-coding-system (, mime-charset))
-       (,@ body))))
+  `(wl-as-coding-system (mime-charset-to-coding-system ,mime-charset)
+     ,@body))
 
 (defalias 'wl-string 'elmo-string)
 (make-obsolete 'wl-string 'elmo-string)
@@ -361,8 +365,6 @@ The objects mapped (cdrs of elements of the ALIST) are shared."
       (setq keys (cdr keys)))
     result))
 
-(eval-when-compile
-  (require 'static))
 (static-unless (fboundp 'pp)
   (defvar pp-escape-newlines t)
   (defun pp (object &optional stream)
@@ -489,7 +491,7 @@ that `read' can handle, whenever this is possible."
       (message "Not a nntp: url."))))
 
 (defmacro wl-concat-list (list separator)
-  (` (mapconcat 'identity (delete "" (delq nil (, list))) (, separator))))
+  `(mapconcat 'identity (delete "" (delq nil ,list)) ,separator))
 
 (defun wl-current-message-buffer ()
   (when (buffer-live-p wl-current-summary-buffer)
@@ -503,13 +505,13 @@ that `read' can handle, whenever this is possible."
 		nil nil))))))
 
 (defmacro wl-kill-buffers (regexp)
-  (` (mapcar (function
-	      (lambda (x)
-		(if (and (buffer-name x)
-			 (string-match (, regexp) (buffer-name x)))
-		    (and (get-buffer x)
-			 (kill-buffer x)))))
-	     (buffer-list))))
+  `(mapcar (function
+	    (lambda (x)
+	      (if (and (buffer-name x)
+		       (string-match ,regexp (buffer-name x)))
+		  (and (get-buffer x)
+		       (kill-buffer x)))))
+	   (buffer-list)))
 
 (defun wl-collect-summary ()
   (let (result)
@@ -568,8 +570,8 @@ that `read' can handle, whenever this is possible."
 (static-if (fboundp 'local-variable-p)
     (defalias 'wl-local-variable-p 'local-variable-p)
   (defmacro wl-local-variable-p (symbol &optional buffer)
-    (` (if (assq (, symbol) (buffer-local-variables (, buffer)))
-	   t))))
+    `(if (assq ,symbol (buffer-local-variables ,buffer))
+	 t)))
 
 (defun wl-number-base36 (num len)
   (if (if (< len 0)
@@ -600,11 +602,11 @@ that `read' can handle, whenever this is possible."
 				      ("Jul" . "07") ("Aug" . "08")
 				      ("Sep" . "09") ("Oct" . "10")
 				      ("Nov" . "11") ("Dec" . "12"))))))
-		(list (string-to-int (concat (nth 6 cts) m
-					     (substring (nth 2 cts) 0 1)))
-		      (string-to-int (concat (substring (nth 2 cts) 1)
-					     (nth 4 cts) (nth 5 cts)
-					     (nth 6 cts))))))))
+		(list (string-to-number (concat (nth 6 cts) m
+						(substring (nth 2 cts) 0 1)))
+		      (string-to-number (concat (substring (nth 2 cts) 1)
+						(nth 4 cts) (nth 5 cts)
+						(nth 6 cts))))))))
     (concat
      (if (memq system-type '(ms-dos emx vax-vms))
 	 (let ((user (downcase (user-login-name))))
@@ -653,9 +655,9 @@ that `read' can handle, whenever this is possible."
 ;;;
 
 (defmacro wl-count-lines ()
-  (` (save-excursion
-       (beginning-of-line)
-       (count-lines 1 (point)))))
+  '(save-excursion
+     (beginning-of-line)
+     (count-lines 1 (point))))
 
 (defun wl-horizontal-recenter ()
   "Recenter the current buffer horizontally."
@@ -871,6 +873,7 @@ This function is imported from Emacs 20.7."
 	    (while flist
 	      (setq folder (wl-folder-get-elmo-folder (car flist))
 		    flist (cdr flist))
+	      (elmo-folder-set-biff-internal folder t)
 	      (when (and (elmo-folder-plugged-p folder)
 			 (elmo-folder-exists-p folder))
 		(setq new-mails
@@ -1014,15 +1017,15 @@ is enclosed by at least one regexp grouping construct."
     (append (list 'format f) specs)))
 
 (defmacro wl-line-formatter-setup (formatter format alist)
-  (` (let (byte-compile-warnings)
-       (setq (, formatter)
-	     (byte-compile
-	      (list 'lambda ()
-		    (wl-line-parse-format (, format) (, alist)))))
-       (when (get-buffer "*Compile-Log*")
-	 (bury-buffer "*Compile-Log*"))
-       (when (get-buffer "*Compile-Log-Show*")
-	 (bury-buffer "*Compile-Log-Show*")))))
+  `(let (byte-compile-warnings)
+     (setq ,formatter
+	   (byte-compile
+	    (list 'lambda ()
+		  (wl-line-parse-format ,format ,alist))))
+     (when (get-buffer "*Compile-Log*")
+       (bury-buffer "*Compile-Log*"))
+     (when (get-buffer "*Compile-Log-Show*")
+       (bury-buffer "*Compile-Log-Show*"))))
 
 (defsubst wl-copy-local-variables (src dst local-variables)
   "Copy value of LOCAL-VARIABLES from SRC buffer to DST buffer."
@@ -1213,6 +1216,15 @@ is enclosed by at least one regexp grouping construct."
   (defalias 'wl-completing-read-multiple 'completing-read-multiple)))
 
 
+(cond
+ ((fboundp 'shell-command-read-minibuffer)
+  (defun wl-read-shell-command (prompt &optional
+				       initial-contents keymap read hist)
+    (shell-command-read-minibuffer prompt default-directory
+				   initial-contents keymap read hist)))
+ (t
+  (defalias 'wl-read-shell-command 'read-from-minibuffer)))
+
 (require 'product)
 (product-provide (provide 'wl-util) (require 'wl-version))
 
