@@ -380,9 +380,10 @@
     (wl-folder-archive-glyph	. wl-archive-folder-icon)
     (wl-folder-pipe-glyph	. wl-pipe-folder-icon)
     (wl-folder-maildir-glyph	. wl-maildir-folder-icon)
-    (wl-folder-nmz-glyph	. wl-nmz-folder-icon)
+    (wl-folder-search-glyph	. wl-search-folder-icon)
     (wl-folder-shimbun-glyph	. wl-shimbun-folder-icon)
     (wl-folder-file-glyph	. wl-file-folder-icon)
+    (wl-folder-access-glyph	. wl-access-folder-icon)
     (wl-folder-trash-empty-glyph . wl-empty-trash-folder-icon)
     (wl-folder-draft-glyph	. wl-draft-folder-icon)
     (wl-folder-queue-glyph	. wl-queue-folder-icon)
@@ -456,6 +457,7 @@
     (define-key keymap "l" 'wl-message-toggle-disp-summary)
     (define-key keymap "\C-c:d" 'wl-message-decrypt-pgp-nonmime)
     (define-key keymap "\C-c:v" 'wl-message-verify-pgp-nonmime)
+    (define-key keymap "w" 'wl-draft)
     (define-key keymap 'button4 'wl-message-wheel-down)
     (define-key keymap 'button5 'wl-message-wheel-up)
     (define-key keymap [(shift button4)] 'wl-message-wheel-down)
@@ -552,9 +554,9 @@ Special commands:
 
 (defalias 'wl-defface 'defface)
 
-(defun wl-read-event-char ()
+(defun wl-read-event-char (&optional prompt)
   "Get the next event."
-  (let ((event (next-command-event)))
+  (let ((event (next-command-event nil prompt)))
     (sit-for 0)
     ;; We junk all non-key events.  Is this naughty?
     (while (not (or (key-press-event-p event)
@@ -565,14 +567,6 @@ Special commands:
 	       (event-to-character event))
 	  event)))
 
-(defun wl-completing-read-multiple (prompt
-				    table
-				    &optional predicate
-				    require-match initial-input)
-  "Read multiple strings in the minibuffer"
-  (split-string (completing-read prompt table predicate require-match
-				 initial-input) ","))
-
 (require 'product)
 (product-provide (provide 'wl-xmas) (require 'wl-version))
 
